#
# spec file for package kokkos
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define major_ver 4
%define minor_ver 1
%define patch_ver 00
%define shlib   libkokkos-%{major_ver}_%{minor_ver}
%global kokkos_desc \
Kokkos Core implements a programming model in C++ for writing performance \
portable applications targeting all major HPC platforms. For that purpose \
it provides abstractions for both parallel execution of code and data \
management.  Kokkos is designed to target complex node architectures with \
N-level memory hierarchies and multiple types of execution resources. It \
currently can use OpenMP, Pthreads and CUDA as backend programming models.

Name:           kokkos
Version:        %{major_ver}.%{minor_ver}.%{patch_ver}
Release:        bp156.1.3
Summary:        A C++ Performance Portability Programming
License:        BSD-3-Clause
Group:          System/Libraries
URL:            https://github.com/kokkos/kokkos
Source0:        kokkos-4.1.00.tar.gz
BuildRequires:  cmake >= 3.16
%if 0%{?suse_version} <= 1500
BuildRequires:  gcc11-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  hwloc-devel
BuildRequires:  memory-constraints
BuildRequires:  ninja
#no support for 32-bit archs https://github.com/kokkos/kokkos/issues/2312
ExcludeArch:    %{ix86} %{arm} powerpc %{sparc}

%description
%{kokkos_desc}

%package -n %{shlib}
Summary:        A C++ Performance Portability Programming Library
Group:          System/Libraries

%description -n %{shlib}
%{kokkos_desc}

This package contains the kokkos library.

%package devel
Summary:        Development package for  %{name} packages
Group:          System/Libraries
Requires:       %{shlib} = %{version}-%{release}
Requires:       hwloc-devel
Conflicts:      trilinos-devel

%description devel
%{kokkos_desc}

This package contains the development files of %{name}.

%prep
%setup -q
sed -i '1c #!/usr/bin/bash' bin/hpcbind bin/runtest

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
%global __builder ninja

%cmake \
  -DCMAKE_BUILD_TYPE=RELWITHDEBINFO \
%if 0%{?suse_version} <= 1500
  -DCMAKE_CXX_COMPILER=g++-11 \
%endif
  -DCMAKE_CXX_FLAGS=-pthread \
  -DCMAKE_INSTALL_INCLUDEDIR=include/kokkos \
  -DKokkos_ENABLE_AGGRESSIVE_VECTORIZATION=ON \
  -DKokkos_ENABLE_DEPRECATED_CODE_4=ON \
  -DKokkos_ENABLE_DEPRECATION_WARNINGS=OFF \
  -DKokkos_ENABLE_HWLOC=ON \
  -DKokkos_ENABLE_TESTS=ON \
  -DKokkos_ENABLE_SERIAL=ON \
  -DKokkos_ENABLE_OPENMP=ON \
  %{nil}
%cmake_build

%install
%cmake_install

%check
export LD_LIBRARY_PATH="%{buildroot}/%{_libdir}:$PWD/build/core/unit_test:${LD_LIBRARY_PATH}"
export OMP_PROC_BIND=false
%ctest --parallel 4 --exclude-regex 'Kokkos_CoreUnitTest_OpenMP|Kokkos_Containers*|Kokkos_Algorithms*'

%post -n %{shlib} -p /sbin/ldconfig
%postun -n %{shlib} -p /sbin/ldconfig

%files -n %{shlib}
%doc README.md
%license LICENSE
%{_libdir}/libkokkos*.so.%{major_ver}.%{minor_ver}*

%files devel
%{_libdir}/libkokkos*.so
%{_libdir}/cmake/Kokkos
%{_includedir}/kokkos
%{_bindir}/nvcc_wrapper
%{_bindir}/hpcbind
%{_bindir}/kokkos_launch_compiler

%changelog
* Wed Jul  5 2023 Vicente Adolfo Bolea Sanchez <vicente.bolea@gmail.com> - 4.1.00
- Update to new upstream release 4.1.00:
  see https://github.com/kokkos/kokkos/blob/4.1.00/CHANGELOG.md
- Use a tarball as Source0 instead of an URL.
* Wed May  3 2023 Vicente Adolfo Bolea Sanchez <vicente.bolea@gmail.com> - 4.0.01
- Update to new upstream release 4.0.01:
  see https://github.com/kokkos/kokkos/blob/62d2b6c879b74b6ae7bd06eb3e5e80139c4708e6/CHANGELOG.md
- Use Ninja for building the project.
* Tue Apr  4 2023 Cezary Skrzyński <czars1988@gmail.com> - 4.0.00
- Update to new upstream release 4.0.00:
  see https://github.com/kokkos/kokkos/blob/master/CHANGELOG.md#400-2023-02-21
- Increase memory limits for build to avoid OpenMP tests running
  out of memory
- Add kokkos-do-not-use-env-as-interpreter.patch to fix rpmlint
  complaint about `env` being used as interpreter
* Tue Apr 26 2022 Jan Engelhardt <jengelh@inai.de>
- Resolve rpmlint report "libkokkos3.x86_64: E:
  shlib-policy-name-error SONAME: libkokkoscontainers.so.3.3.0,
  expected package suffix: 3_3_0"
* Tue Oct 12 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Remove random constraint adjustments again, and use a global
  lower limit of 6 GB of memory (minimum for the OMP tests).
- Limit the number of parallel jobs and OMP threads in the unit
  tests, to keep the required memory bounded.
  This way, even architectures with many cores and comparatively
  low memory can build successfully.
* Sun Oct  3 2021 Sarah Kriesch <sarah.kriesch@opensuse.org>
- New entries in constraints file because of missing build nodes with
  18GB of memory for s390x and PPC:
  - 2GB for memoryperjob at x86, riscv64 and s390x
  - aarch64 3GB for memoryperjob because of "Out of memory" with 2GB
  - PPC64 and PPC64le with 1GB for memoryperjob because of missing
    node capacity
* Sat Dec 19 2020 Christoph Junghans <junghans@votca.org>
- dropped 3308.patch - merged upstream
- Version bump to 3.3.00:
  - Features:
  - Require C++14 as minimum C++ standard. C++17 and C++20 are
    supported too.
  - HIP backend is nearly feature complete. Kokkos Dynamic Task
    Graphs are missing.
  - Major update for OpenMPTarget: many capabilities now work.
    For details contact us.
  - Added DPC++/SYCL backend: primary capabilites are working.
  - Added Kokkos Graph API analogous to CUDA Graphs.
  - Added parallel_scan support with TeamThreadRange
    [gh#kokkos/kokkos#3536]
  - Added Logical Memory Spaces [gh#kokkos/kokkos#3546]
  - Added initial half precision support [gh#kokkos/kokkos#3439]
  - Experimental feature: control cuda occupancy
    [gh#kokkos/kokkos#3379]
  - Implemented enhancements Backends and Archs:
  - Add a64fx and fujitsu Compiler support
    [gh#kokkos/kokkos#3614]
  - Adding support for AMD gfx908 archictecture
    [gh#kokkos/kokkos#3375]
  - SYCL parallel_for MDRangePolicy [gh#kokkos/kokkos#3583]
  - SYCL add parallel_scan [gh#kokkos/kokkos#3577]
  - SYCL custom reductions [gh#kokkos/kokkos#3544]
  - SYCL Enable container unit tests [gh#kokkos/kokkos#3550]
  - SYCL feature level 5 [gh#kokkos/kokkos#3480]
  - SYCL Feature level 4 (parallel_for) [gh#kokkos/kokkos#3474]
  - SYCL feature level 3 [gh#kokkos/kokkos#3451]
  - SYCL feature level 2 [gh#kokkos/kokkos#3447]
  - OpenMPTarget: Hierarchial reduction for + operator on
    scalars [gh#kokkos/kokkos#3504]
  - OpenMPTarget hierarchical [gh#kokkos/kokkos#3411]
  - HIP Add Impl::atomic_[store,load] [gh#kokkos/kokkos#3440]
  - HIP enable global lock arrays [gh#kokkos/kokkos#3418]
  - HIP Implement multiple occupancy paths for various HIP
    kernel launchers [gh#kokkos/kokkos#3366]
  - Implemented enhancements Policies:
  - MDRangePolicy: Let it be semiregular [gh#kokkos/kokkos#3494]
  - MDRangePolicy: Check narrowing conversion in construction
    [gh#kokkos/kokkos#3527]
  - MDRangePolicy: CombinedReducers support
    [gh#kokkos/kokkos#3395]
  - Kokkos Graph: Interface and Default Implementation
    [gh#kokkos/kokkos#3362]
  - Kokkos Graph: add Cuda Graph implementation
    [gh#kokkos/kokkos#3369]
  - TeamPolicy: implemented autotuning of team sizes and vector
    lengths [gh#kokkos/kokkos#3206]
  - RangePolicy: Initialize all data members in default
    constructor [gh#kokkos/kokkos#3509]
  - Implemented enhancements BuildSystem:
  - Auto-generate core test files for all backends
    [gh#kokkos/kokkos#3488]
  - Avoid rewriting test files when calling cmake
    [gh#kokkos/kokkos#3548]
  - RULE_LAUNCH_COMPILE and RULE_LAUNCH_LINK system for
    nvcc_wrapper [gh#kokkos/kokkos#3136]
  - Adding -include as a known argument to nvcc_wrapper
    [gh#kokkos/kokkos#3434]
  - Install hpcbind script [gh#kokkos/kokkos#3402]
  - cmake/kokkos_tribits.cmake: add parsing for args
    [gh#kokkos/kokkos#3457]
  - Implemented enhancements Tools:
  - Changed namespacing of
    Kokkos::Tools::Impl::Impl::tune_policy
    [gh#kokkos/kokkos#3455]
  - Delegate to an impl allocate/deallocate method to allow
    specifying a SpaceHandle for MemorySpaces
    [gh#kokkos/kokkos#3530]
  - Use the Kokkos Profiling interface rather than the Impl
    interface [gh#kokkos/kokkos#3518]
  - Runtime option for tuning [gh#kokkos/kokkos#3459]
  - Dual View Tool Events [gh#kokkos/kokkos#3326]
  - Implemented enhancements Other:
  - Abort on errors instead of just printing
    [gh#kokkos/kokkos#3528]
  - Enable C++14 macros unconditionally [gh#kokkos/kokkos#3449]
  - Make ViewMapping trivially copyable [gh#kokkos/kokkos#3436]
  - Rename struct ViewMapping to class [gh#kokkos/kokkos#3435]
  - Replace enums in Kokkos_ViewMapping.hpp (removes -Wextra)
    [gh#kokkos/kokkos#3422]
  - Use bool for enums representing bools
    [gh#kokkos/kokkos#3416]
  - Fence active instead of default execution space instances
    [gh#kokkos/kokkos#3388]
  - Refactor parallel_reduce fence usage [gh#kokkos/kokkos#3359]
  - Moved Space EBO helpers to Kokkos_EBO
    [gh#kokkos/kokkos#3357]
  - Add remove_cvref type trait [gh#kokkos/kokkos#3340]
  - Adding identity type traits and update definition of
    identity_t alias [gh#kokkos/kokkos#3339]
  - Add is_specialization_of type trait [gh#kokkos/kokkos#3338]
  - Make ScratchMemorySpace semi-regular [gh#kokkos/kokkos#3309]
  - Optimize min/max atomics with early exit on no-op case
    [gh#kokkos/kokkos#3265]
  - Refactor Backend Development [gh#kokkos/kokkos#2941]
  - Fixed bugs:
  - Fixup MDRangePolicy construction from Kokkos arrays
    [gh#kokkos/kokkos#3591]
  - Add atomic functions for unsigned long long using gcc
    built-in [gh#kokkos/kokkos#3588]
  - Fixup silent pointless comparison with zero in
    checked_narrow_cast (compiler workaround)
    [gh#kokkos/kokkos#3566]
  - Fixes for ROCm 3.9 [gh#kokkos/kokkos#3565]
  - Fix windows build issues which crept in for the CUDA build
    [gh#kokkos/kokkos#3532]
  - HIP Fix atomics of large data types and clean up lock arrays
    [gh#kokkos/kokkos#3529]
  - Pthreads fix exception resulting from 0 grain size
    [gh#kokkos/kokkos#3510]
  - Fixup do not require atomic operation to be default
    constructible [gh#kokkos/kokkos#3503]
  - Fix race condition in HIP backend [gh#kokkos/kokkos#3467]
  - Replace KOKKOS_DEBUG with KOKKOS_ENABLE_DEBUG
    [gh#kokkos/kokkos#3458]
  - Fix multi-stream team scratch space definition for HIP
    [gh#kokkos/kokkos#3398]
  - HIP fix template deduction [gh#kokkos/kokkos#3393]
  - Fix compiling with HIP and C++17 [gh#kokkos/kokkos#3390]
  - Fix sigFPE in HIP blocksize deduction
    [gh#kokkos/kokkos#3378]
  - Type alias change: replace CS with CTS to avoid conflicts
    with NVSHMEM [gh#kokkos/kokkos#3348]
  - Clang compilation of CUDA backend on Windows
    [gh#kokkos/kokkos#3345]
  - Fix HBW support [gh#kokkos/kokkos#3343]
  - Added missing fences to unique token [gh#kokkos/kokkos#3260]
  - Incompatibilities:
  - Remove unused utilities (forward, move, and expand_variadic)
    from Kokkos::Impl [gh#kokkos/kokkos#3535]
  - Remove unused traits [gh#kokkos/kokkos#3534]
  - HIP: Remove old HCC code [gh#kokkos/kokkos#3301]
  - Prepare for deprecation of ViewAllocateWithoutInitializing
    [gh#kokkos/kokkos#3264]
  - Remove ROCm backend [gh#kokkos/kokkos#3148]
* Sun Sep 20 2020 Christoph Junghans <junghans@votca.org>
- added 3308.patch to fix naming of printer-tool
- Version bump to 3.2.00:
  - Implemented enhancements:
  - HIP:Enable stream in HIP [gh#kokkos/kokkos#3163]
  - HIP:Add support for shuffle reduction for the HIP backend
    [gh#kokkos/kokkos#3154]
  - HIP:Add implementations of missing HIPHostPinnedSpace
    methods for LAMMPS [gh#kokkos/kokkos#3137]
  - HIP:Require HIP 3.5.0 or higher [gh#kokkos/kokkos#3099]
  - HIP:WorkGraphPolicy for HIP [gh#kokkos/kokkos#3096]
  - OpenMPTarget: Significant update to the new experimental
    backend. Requires C++17, works on Intel GPUs, reference
    counting fixes. [gh#kokkos/kokkos#3169]
  - Windows Cuda support [gh#kokkos/kokkos#3018]
  - Pass -Wext-lambda-captures-this to NVCC when support for
    __host__ __device__ lambda is enabled from CUDA 11
    [gh#kokkos/kokkos#3241]
  - Use explicit staging buffer for constant memory kernel
    launches and cleanup host/device synchronization
    [gh#kokkos/kokkos#3234]
  - Various fixup to policies including making TeamPolicy
    default constructible and making RangePolicy and TeamPolicy
    assignable: [gh#kokkos/kokkos#3202], [gh#kokkos/kokkos#3203],
    [gh#kokkos/kokkos#3196]
  - Annotations for DefaultExectutionSpace and
    DefaultHostExectutionSpace to use in static analysis
    [gh#kokkos/kokkos#3189]
  - Add documentation on using Spack to install Kokkos and
    developing packages that depend on Kokkos
    [gh#kokkos/kokkos#3187]
  - Add OpenMPTarget backend flags for NVC++ compiler
    [gh#kokkos/kokkos#3185]
  - Move deep_copy/create_mirror_view on
    Experimental::OffsetView into Kokkos:: namespace
    [gh#kokkos/kokkos#3166]
  - Allow for larger block size in HIP [gh#kokkos/kokkos#3165]
  - View: Added names of Views to the different View
    initialize/free kernels [gh#kokkos/kokkos#3159]
  - Cuda: Caching cudaFunctorAttributes and whether L1/Shmem
    prefer was set [gh#kokkos/kokkos#3151]
  - BuildSystem: Improved performance in default configuration
    by defaulting to Release build [gh#kokkos/kokkos#3131]
  - Cuda: Update CUDA occupancy calculation
    [gh#kokkos/kokkos#3124]
  - Vector: Adding data() to Vector [gh#kokkos/kokkos#3123]
  - BuildSystem: Add CUDA Ampere configuration support
    [gh#kokkos/kokkos#3122]
  - General: Apply [[noreturn]] to Kokkos::abort when applicable
    [gh#kokkos/kokkos#3106]
  - TeamPolicy: Validate storage level argument passed to
    TeamPolicy::set_scratch_size() [gh#kokkos/kokkos#3098]
  - BuildSystem: Make kokkos_has_string() function in
    Makefile.kokkos case insensitive [gh#kokkos/kokkos#3091]
  - Modify KOKKOS_FUNCTION macro for clang-tidy analysis
    [gh#kokkos/kokkos#3087]
  - Move allocation profiling to allocate/deallocate calls
    [gh#kokkos/kokkos#3084]
  - BuildSystem: FATAL_ERROR when attempting in-source build
    [gh#kokkos/kokkos#3082]
  - Change enums in ScatterView to types [gh#kokkos/kokkos#3076]
  - HIP: Changes for new compiler/runtime
    [gh#kokkos/kokkos#3067]
  - Extract and use get_gpu [gh#kokkos/kokkos#3061] ,
    [gh#kokkos/kokkos#3048]
  - Add is_allocated to View-like containers
    [gh#kokkos/kokkos#3059]
  - Combined reducers for scalar references
    [gh#kokkos/kokkos#3052]
  - Add configurable capacity for UniqueToken
    [gh#kokkos/kokkos#3051]
  - Add installation testing [gh#kokkos/kokkos#3034]
  - HIP: Add UniqueToken [gh#kokkos/kokkos#3020]
  - Autodetect number of devices [gh#kokkos/kokkos#3013]
  - Fixed bugs:
  - Check error code from cudaStreamSynchronize in CUDA fences
    [gh#kokkos/kokkos#3255]
  - Fix issue with C++ standard flags when using nvcc\_wrapper
    with PGI [gh#kokkos/kokkos#3254]
  - Add missing threadfence in lock-based atomics
    [gh#kokkos/kokkos#3208]
  - Fix dedup of linker flags for shared lib on CMake <=3.12
    [gh#kokkos/kokkos#3176]
  - Fix memory leak with CUDA streams [gh#kokkos/kokkos#3170]
  - BuildSystem: Fix OpenMP Target flags for Cray
    [gh#kokkos/kokkos#3161]
  - ScatterView: fix for OpenmpTarget remove inheritance from
    reducers [gh#kokkos/kokkos#3162]
  - BuildSystem: Set OpenMP flags according to host compiler
    [gh#kokkos/kokkos#3127]
  - OpenMP: Fix logic for nested omp in partition_master bug
    [gh#kokkos/kokkos#3101]
  - nvcc_wrapper: send --cudart to nvcc instead of host compiler
    [gh#kokkos/kokkos#3092]
  - BuildSystem: Fixes for Cuda/11 and c++17
    [gh#kokkos/kokkos#3085]
  - HIP: Fix print_configuration [gh#kokkos/kokkos#3080]
  - Conditionally define get_gpu [gh#kokkos/kokkos#3072]
  - Fix bounds for ranges in random number generator
    [gh#kokkos/kokkos#3069]
  - Fix Cuda minor arch check [gh#kokkos/kokkos#3035]
  - BuildSystem: Add -expt-relaxed-constexpr flag to
    nvcc_wrapper [gh#kokkos/kokkos#3021]
  - Incompatibilities:
  - Remove ETI support [gh#kokkos/kokkos#3157]
  - Remove KOKKOS_INTERNAL_ENABLE_NON_CUDA_BACKEND
    [gh#kokkos/kokkos#3147]
  - Remove core/unit_test/config [gh#kokkos/kokkos#3146]
  - Removed the preprocessor branch for KOKKOS_ENABLE_PROFILING
    [gh#kokkos/kokkos#3115]
  - Disable profiling with MSVC [gh#kokkos/kokkos#3066]
  - Closed issues:
  - Silent error (Validate storage level arg to
    set_scratch_size) [gh#kokkos/kokkos#3097]
  - Remove KOKKKOS_ENABLE_PROFILING Option
    [gh#kokkos/kokkos#3095]
  - Cuda 11 -> allow C++17 [gh#kokkos/kokkos#3083]
  - In source build failure not explained
    [gh#kokkos/kokkos#3081]
  - Allow naming of Views for initialization kernel
    [gh#kokkos/kokkos#3070]
  - DefaultInit tests failing when using CTest resource
    allocation feature [gh#kokkos/kokkos#3040]
  - Add installation testing. [gh#kokkos/kokkos#3037]
  - nvcc_wrapper needs to handle -expt-relaxed-constexpr flag
    [gh#kokkos/kokkos#3017]
  - CPU core oversubscription warning on macOS with OpenMP
    backend [gh#kokkos/kokkos#2996]
  - Default behavior of KOKKOS_NUM_DEVICES to use all devices
    available [gh#kokkos/kokkos#2975]
  - Assert blocksize > 0 [gh#kokkos/kokkos#2974]
  - Add ability to assign kokkos profile function from
    executable [gh#kokkos/kokkos#2973]
  - ScatterView Support for the pre/post increment operator
    [gh#kokkos/kokkos#2967]
  - Compiler issue: Cuda build with clang 10 has errors with the
    atomic unit tests [gh#kokkos/kokkos#3237]
  - Incompatibility of flags for C++ standard with PGI v20.4 on
    Power9/NVIDIA V100 system [gh#kokkos/kokkos#3252]
  - Error configuring as subproject [gh#kokkos/kokkos#3140]
  - CMake fails with Nvidia compilers when the GPU architecture
    option is not supplied (Fix configure with OMPT and Cuda)
    [gh#kokkos/kokkos#3207]
  - PGI compiler being passed the gcc -fopenmp flag
    [gh#kokkos/kokkos#3125]
  - Cuda: Memory leak when using CUDA stream
    [gh#kokkos/kokkos#3167]
  - RangePolicy has an implicitly deleted assignment operator
    [gh#kokkos/kokkos#3192]
  - MemorySpace::allocate needs to have memory pool counting.
    [gh#kokkos/kokkos#3064]
  - Missing write fence for lock based atomics on CUDA
    [gh#kokkos/kokkos#3038]
  - CUDA compute capability version check problem
    [gh#kokkos/kokkos#3026]
  - Make DynRankView fencing consistent [gh#kokkos/kokkos#3014]
  - nvcc_wrapper cant handle -Xcompiler -o out.o
    [gh#kokkos/kokkos#2993]
  - Reductions of non-trivial types of size 4 fail in CUDA shfl
    operations [gh#kokkos/kokkos#2990]
  - complex_double misalignment in reduce, clang+CUDA
    [gh#kokkos/kokkos#2989]
  - Span of degenerated (zero-length) subviews is not zero in
    some special cases [gh#kokkos/kokkos#2979]
  - Rank 1 custom layouts dont work as expected.
    [gh#kokkos/kokkos#2840]
* Thu Aug 20 2020 Martin Liška <mliska@suse.cz>
- Use memoryperjob constraint instead of %%limit_build macro.
* Wed May  6 2020 Christoph Junghans <junghans@votca.org>
- drop fix-StackTraceTest.patch, merged upstream
- Version bump to 3.1.01:
  see https://github.com/kokkos/kokkos/blob/master/CHANGELOG.md
  * Fixed bugs:
  - Fix complex_double misalignment in reduce, clang+CUDA
    [gh#kokkos/kokkos#2989]
  - Fix compilation fails when profiling disabled and CUDA
    enabled [gh#kokkos/kokkos#3001]
  - Fix cuda reduction of non-trivial scalars of size 4
    [gh#kokkos/kokkos#2990]
  - Configure and install version file when building in Trilinos
    [gh#kokkos/kokkos#2957]
  - Fix OpenMPTarget build missing include and namespace
    [gh#kokkos/kokkos#3000]
  - fix typo in KOKKOS_SET_EXE_PROPERTY() [gh#kokkos/kokkos#2959]
  - Fix non-zero span subviews of zero sized subviews
    [gh#kokkos/kokkos#2979]
* Wed Apr 22 2020 Christoph Junghans <junghans@votca.org>
- add missing Conflicts: marker
* Fri Apr 17 2020 Christoph Junghans <junghans@votca.org>
- added fix-StackTraceTest.patch to fix StackTraceTest test
- Version bump to 3.1.00:
  see https://github.com/kokkos/kokkos/blob/master/CHANGELOG.md
  * Features:
  - HIP Support for AMD
  - OpenMPTarget Support with clang
  - Windows VS19 (Serial) Support [gh#kokkos/kokkos#1533]
  * Implemented enhancements:
  - generate_makefile.bash should allow tests to be disabled
    [gh#kokkos/kokkos#2886]
  - clang/7+cuda/9 build -Werror-unused parameter error in
    nightly test [gh#kokkos/kokkos#2884]
  - ScatterView memory space is not user settable
    [gh#kokkos/kokkos#2826]
  - clang/8+cuda/10.0 build error with c++17
    [gh#kokkos/kokkos#2809]
  - warnings.... [gh#kokkos/kokkos#2805]
  - Kokkos version in cpp define [gh#kokkos/kokkos#2787]
  - Remove Defunct QThreads Backend [gh#kokkos/kokkos#2751]
  - Improve Kokkos::fence behavior with multiple execution
    spaces [gh#kokkos/kokkos#2659]
  - polylithic(?) initialization of Kokkos
    [gh#kokkos/kokkos#2658]
  - Unnecessary(?) check for host execution space initialization
    from Cuda initialization [gh#kokkos/kokkos#2652]
  - Kokkos error reporting failures with CUDA GPUs in exclusive
    mode [gh#kokkos/kokkos#2471]
  - atomicMax equivalent (and other atomics)
    [gh#kokkos/kokkos#2401]
  - Fix alignment for Kokkos::complex [gh#kokkos/kokkos#2255]
  - Warnings with Cuda 10.1 [gh#kokkos/kokkos#2206]
  - dual view with Kokkos::ViewAllocateWithoutInitializing
    [gh#kokkos/kokkos#2188]
  - Check error code from
    cudaOccupancyMaxActiveBlocksPerMultiprocessor
    [gh#kokkos/kokkos#2172]
  - Add non-member Kokkos::resize/realloc for DualView
    [gh#kokkos/kokkos#2170]
  - Construct DualView without initialization
    [gh#kokkos/kokkos#2046]
  - Expose is_assignable to determine if one view can be
    assigned to another [gh#kokkos/kokkos#1936]
  - profiling label [gh#kokkos/kokkos#1935]
  - team_broadcast of bool failed on CUDA backend
    [gh#kokkos/kokkos#1908]
  - View static_extent [gh#kokkos/kokkos#660]
  - Misleading Kokkos::Cuda::initialize ERROR message when
    compiled for wrong GPU architecture [gh#kokkos/kokkos#1944]
  - Cryptic Error When Malloc Fails [gh#kokkos/kokkos#2164]
  - Drop support for intermediate standards in CMake
    [gh#kokkos/kokkos#2336]
  * Fixed bugs:
  - DualView sync_device with length zero creates cuda errors
    [gh#kokkos/kokkos#2946]
  - building with nvcc and clang (or clang based XL) as host
    compiler: "Kokkos::atomic_fetch_min(volatile int *, int)"
    has already been defined [gh#kokkos/kokkos#2903]
  - Cuda 9.1,10.1 debug builds failing due to
  - Werror=unused-parameter [gh#kokkos/kokkos#2880]
  - clang -Werror: Kokkos_FixedBufferMemoryPool.hpp:140:28:
    error: unused parameter 'alloc_size' [gh#kokkos/kokkos#2869]
  - intel/16.0.1, intel/17.0.1 nightly build failures with
    debugging enabled [gh#kokkos/kokkos#2867]
  - intel/16.0.1 debug build errors [gh#kokkos/kokkos#2863]
  - xl/16.1.1 with cpp14, openmp build, nightly test failures
    [gh#kokkos/kokkos#2856]
  - Intel nightly test failures: team_vector
    [gh#kokkos/kokkos#2852]
  - Kokkos Views with intmax/2<N<intmax can hang during
    construction [gh#kokkos/kokkos#2850]
  - workgraph_fib test seg-faults with threads backend and hwloc
    [gh#kokkos/kokkos#2797]
  - cuda.view_64bit test hangs on Power8+Kepler37 system -
    develop and 2.9.00 branches [gh#kokkos/kokkos#2771]
  - device_type for Kokkos_Random ? [gh#kokkos/kokkos#2693]
  - "More than one tag given" error in Experimental::require()
    [gh#kokkos/kokkos#2608]
  - Segfault on Marvell from our finalization stack
    [gh#kokkos/kokkos#2542]
* Thu Feb 27 2020 Christoph Junghans <junghans@votca.org>
- Version bump to 3.0.00 - see https://github.com/kokkos/kokkos/blob/master/CHANGELOG.md
  Implemented enhancements:
  + BuildSystem: Standalone Modern CMake Support #2104
  + StyleFormat: ClangFormat Style #2157
  + Documentation: Document build system and CMake philosophy #2263
  + BuildSystem: Add Alias with Namespace Kokkos:: to Interal Libraries #2530
  + BuildSystem: Universal Kokkos find_package #2099
  + BuildSystem: Dropping support for Kokkos_{DEVICES,OPTIONS,ARCH} in CMake #2329
  + BuildSystem: Set Kokkos_DEVICES and Kokkos_ARCH variables in exported CMake configuration #2193
  + BuildSystem: Drop support for CUDA 7 and CUDA 8 #2489
  + BuildSystem: Drop CMake option SEPARATE_TESTS #2266
  + BuildSystem: Support expt-relaxed-constexpr same as expt-extended-lambda #2411
  + BuildSystem: Add Xnvlink to command line options allowed in nvcc_wrapper #2197
  + BuildSystem: Install Kokkos config files and target files to lib/cmake/Kokkos #2162
  + BuildSystem: nvcc_wrappers and c++ 14 #2035
  + BuildSystem: Kokkos version major/version minor (Feature request) #1930
  + BuildSystem: CMake namespaces (and other modern cmake cleanup) #1924
  + BuildSystem: Remove capability to install Kokkos via GNU Makefiles #2332
  + Documentation: Remove PDF ProgrammingGuide in Kokkos replace with link #2244
  + View: Add Method to Resize View without Initialization #2048
  + Vector: implement “insert” method for Kokkos_Vector (as a serial function on host) #2437
* Tue Feb  4 2020 Christoph Junghans <junghans@votca.org>
- Initial commit
